@@ -28,7 +28,7 @@ our @EXPORT = qw(
 	is_domain_label
 );
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 
@@ -444,6 +444,9 @@ sub is_domain_label {
 
         return unless defined($value);
 
+	#Fix Bug: 41033
+	return if ($value =~ /\n/);
+
 	my $opt = (defined $self)?$self:(shift);
 
 	# bail if we are dealing with more then just a hostname
